Brian2GeNN
==========

Brian 2 frontend to the GeNN simulator

[![PyPI package](https://img.shields.io/pypi/v/Brian2GeNN.svg)](https://pypi.python.org/pypi/Brian2)
[![Documentation Status](https://readthedocs.org/projects/brian2genn/badge/?version=stable)](https://brian2genn.readthedocs.io/en/stable/?badge=stable)
[![Build Status](https://dev.azure.com/brian-team/Brian2GeNN/_apis/build/status/brian-team.brian2genn)](https://dev.azure.com/brian-team/Brian2GeNN/_build/latest?definitionId=1)

If you use BrianGeNN for your published research, we kindly ask you to cite our article:  
Marcel Stimberg, Dan F. M. Goodman, and Thomas Nowotny. “Brian2GeNN: Accelerating Spiking Neural Network Simulations with Graphics Hardware.” Sci Rep 10 (January 2020): 410. [doi: 10.1038/s41598-019-54957-7](https://doi.org/10.1038/s41598-019-54957-7).
